@@ -755,5 +755,24 @@ def pausar(tempo=False):
         
 #usado quando uma ação precisa de um intervalo entre uma
 #execução e outra
+#o usuário deve escolher entre usar a função de período ou
+#frequência
 esperar = time.sleep
-frequencia = pygame.time.Clock()
\ No newline at end of file
+definir_frequencia = pygame.time.Clock().tick
+def definir_periodo( periodo ): 
+    pygame.time.Clock().tick( 1/periodo )
+
+
+#roda ação em paralelo
+def rodar_em_paralelo( funcao, argumentos = [] ):
+    if( argumentos == [] ):
+        threading.Thread( target= funcao ).start()
+    else:
+        threading.Thread( target= funcao, args = argumentos ).start()
+
+#verifica estado do jogo
+def obter_estado_do_jogo():
+    if( rodar_threading == True ):
+        return "rodando"
+    else:
+        return "fechado"
